@@ -1,5 +1,4 @@
 import warnings
-from collections import defaultdict
 from enum import Enum, unique
 from typing import Any, Dict, List, Optional, Union
 
@@ -76,10 +75,10 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
 
     def __init__(
         self,
-        embs: Union[List, np.ndarray] = None,
-        probs: Union[List, np.ndarray] = None,
-        logits: Union[List, np.ndarray] = None,
-        ids: Union[List, np.ndarray] = None,
+        embs: Optional[Union[List, np.ndarray]] = None,
+        probs: Optional[Union[List, np.ndarray]] = None,
+        logits: Optional[Union[List, np.ndarray]] = None,
+        ids: Optional[Union[List, np.ndarray]] = None,
         split: str = "",
         epoch: Optional[int] = None,
         inference_name: Optional[str] = None,
@@ -122,7 +121,6 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         * embs, probs, and ids must exist and be the same length
         :return:
         """
-        get_dq_logger().debug("Handling logits and probs", split=self.split)
         has_logits = self._has_len(self.logits)
         has_probs = self._has_len(self.probs)
         if has_logits:
@@ -133,7 +131,6 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
             warnings.warn("Usage of probs is deprecated, use logits instead")
             self.probs = self._convert_tensor_ndarray(self.probs, "Prob")
 
-        get_dq_logger().debug("Converting inputs to numpy arrays", split=self.split)
         self.embs = self._convert_tensor_ndarray(self.embs, "Embedding")
         self.ids = self._convert_tensor_ndarray(self.ids)
 
@@ -141,7 +138,6 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         probs_len = len(self.probs)
         ids_len = len(self.ids)
 
-        get_dq_logger().debug("Validating embedding shape", split=self.split)
         assert self.embs.ndim == 2, "Only one embedding vector is allowed per input."
 
         assert embs_len and probs_len and ids_len, (
@@ -177,23 +173,22 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         super().write_model_output(model_output)
 
     def _get_data_dict(self) -> Dict[str, Any]:
-        data = defaultdict(list)
-        for record_id, prob, emb in zip(self.ids, self.probs, self.embs):
-            # Handle binary classification by making it 2-class classification
-            p = [1 - prob[0], prob[0]] if len(prob) == 1 else prob
-            record = {
-                "id": record_id,
-                "epoch": self.epoch,
-                "split": Split[self.split].value,
-                "emb": emb,
-                "prob": p,
-                "pred": int(np.argmax(prob)),
-                "data_schema_version": __data_schema_version__,
-            }
-            if self.split == Split.inference:
-                record.update(inference_name=self.inference_name)
-            for k in record.keys():
-                data[k].append(record[k])
+        # Handle the binary case by converting it to 2-class classification
+        probs = np.array(self.probs)
+        if probs.shape[-1] == 1:
+            self.probs = np.column_stack((1 - probs, probs))
+        num_samples_in_batch = len(self.ids)
+        data = {
+            "id": self.ids,
+            "emb": self.embs,
+            "prob": self.probs,
+            "pred": np.argmax(self.probs, axis=1),
+            "split": [Split[self.split].value] * num_samples_in_batch,
+            "data_schema_version": [__data_schema_version__] * num_samples_in_batch,
+            "epoch": [self.epoch] * num_samples_in_batch,
+        }
+        if self.split == Split.inference:
+            data["inference_name"] = [self.inference_name] * num_samples_in_batch
         return data
 
     def _set_num_labels(self, data: Dict) -> None:
